==> Products.ContentWellPortlets-1.0.tar.gz: Products.ContentWellPortlets-1.0/Products/ContentWellPortlets/browser/viewlets.py <==
from zope.component import getMultiAdapter
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from plone.app.layout.viewlets.common import ViewletBase
from Products.CMFCore.utils import getToolByName

class PortletsAboveViewlet(ViewletBase):
    render = ViewPageTemplateFile('templates/portletsabovecontent.pt')
        
    def update(self):
        '''
        Define everything we want to call in the template
        '''
        context_state = getMultiAdapter((self.context, self.request), name=u'plone_context_state')
        self.manageUrl = str(context_state.view_url()) + '/@@manage-portletsabovecontent'
        
        ## This is the way it's done in plone.app.portlets.manager, so we'll do the same
        mt = getToolByName(self.context, 'portal_membership')
        self.canManagePortlets = mt.checkPermission('Portlets: Manage portlets', self.context)


class PortletsBelowViewlet(ViewletBase):
    render = ViewPageTemplateFile('templates/portletsbelowcontent.pt')
        
    def update(self):
        '''
        Define everything we want to call in the template
        '''
        context_state = getMultiAdapter((self.context, self.request), name=u'plone_context_state')
        self.manageUrl = str(context_state.view_url()) + '/@@manage-portletsbelowcontent'
        
        ## This is the way it's done in plone.app.portlets.manager, so we'll do the same
        mt = getToolByName(self.context, 'portal_membership')
        self.canManagePortlets = mt.checkPermission('Portlets: Manage portlets', self.context)

==> Products.ContentWellPortlets-1.1.tar.gz: Products.ContentWellPortlets-1.1/Products/ContentWellPortlets/browser/viewlets.py <==
from zope.component import getMultiAdapter
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from plone.app.layout.viewlets.common import ViewletBase
from Products.CMFCore.utils import getToolByName

class PortletsAboveViewlet(ViewletBase):
    render = ViewPageTemplateFile('templates/portletsabovecontent.pt')
        
    def update(self):
        """
        Define everything we want to call in the template
        """
        context_state = getMultiAdapter((self.context, self.request), name=u'plone_context_state')
        self.manageUrl =  '%s/@@manage-portletsabovecontent' % context_state.view_url()
        
        ## This is the way it's done in plone.app.portlets.manager, so we'll do the same
        mt = getToolByName(self.context, 'portal_membership')
        self.canManagePortlets = mt.checkPermission('Portlets: Manage portlets', self.context)


class PortletsBelowViewlet(ViewletBase):
    render = ViewPageTemplateFile('templates/portletsbelowcontent.pt')
        
    def update(self):
        """
        Define everything we want to call in the template
        """
        context_state = getMultiAdapter((self.context, self.request), name=u'plone_context_state')
        self.manageUrl =  '%s/@@manage-portletsbelowcontent' % context_state.view_url()
        
        ## This is the way it's done in plone.app.portlets.manager, so we'll do the same
        mt = getToolByName(self.context, 'portal_membership')
        self.canManagePortlets = mt.checkPermission('Portlets: Manage portlets', self.context)
